@@ -88,8 +88,6 @@ class AbstractAdapter(object):
 
         if hasattr(self.config, 'timeout'):
             socket.setdefaulttimeout(self.config.timeout)
-        elif socket.getdefaulttimeout() is None:
-            socket.setdefaulttimeout(10)
 
         # Add in configured middlewares
         if hasattr(self.config, '_middlewares'):
